@@ -35,9 +35,12 @@
 #define CODEC_CURR_TRACKED_BUFFER           CODEC_NUM_TRACKED_BUFFERS
 
 //BRC
-#define BRC_IMG_STATE_SIZE_PER_PASS         128
-#define BRC_IMG_STATE_SIZE_PER_PASS_G10     144
-#define BRC_IMG_STATE_SIZE_PER_PASS_G11     192
+#define BRC_IMG_STATE_SIZE_PER_PASS                128
+#define BRC_IMG_STATE_SIZE_PER_PASS_G10            144
+#define BRC_IMG_STATE_SIZE_PER_PASS_G11            192
+#define BRC_MAX_BITRATE_RATIO                      1.5  // maxBitrate = BRC_MAX_BITRATE_RATIO * targetBitrate
+#define BRC_DEFAULT_CPB_IN_SEC                     2    // bufferSize = BRC_DEFAULT_CPB_IN_SEC * maxBitrate
+#define CODECHAL_ENCODE_SCENE_CHANGE_DETECTED_MASK 0xffff
 
 // Quality/Performance differentiators for HSW AVC Encode
 #define NUM_TARGET_USAGE_MODES 8
@@ -50,41 +53,15 @@
 #define CODEC_WP_OUTPUT_L0_START        0
 #define CODEC_WP_OUTPUT_L1_START        6
 
-#define CODEC_720P_MAX_PIC_WIDTH       1280
-#define CODEC_720P_MAX_PIC_HEIGHT      1280
-
-#define CODEC_MAX_PIC_WIDTH            1920
-#define CODEC_MAX_PIC_HEIGHT           1920                // Tablet usage in portrait mode, image resolution = 1200x1920, so change MAX_HEIGHT to 1920
-
-#define CODEC_2K_MAX_PIC_WIDTH         2048
-#define CODEC_2K_MAX_PIC_HEIGHT        2048
-
-#define CODEC_4K_VC1_MAX_PIC_WIDTH     3840
-#define CODEC_4K_VC1_MAX_PIC_HEIGHT    3840
-
-#define CODEC_4K_MAX_PIC_WIDTH         4096
-#define CODEC_4K_MAX_PIC_HEIGHT        4096
-
-#define CODEC_8K_MAX_PIC_WIDTH    8192
-#define CODEC_8K_MAX_PIC_HEIGHT   8192
-
-#define CODEC_16K_MAX_PIC_WIDTH        16384
-#define CODEC_12K_MAX_PIC_HEIGHT       12288
-#define CODEC_16K_MAX_PIC_HEIGHT       16384
-
-#define CODECHAL_MAD_BUFFER_SIZE                4 // buffer size is 4 bytes
-
-#define CODEC_128_MIN_PIC_WIDTH        128
-#define CODEC_96_MIN_PIC_HEIGHT        96
-#define CODEC_128_MIN_PIC_HEIGHT       128
-
 // HME
 #define SCALE_FACTOR_2x     2
 #define SCALE_FACTOR_4x     4
 #define SCALE_FACTOR_16x    16
 #define SCALE_FACTOR_32x    32
 
-#define CODECHAL_VP9_MB_CODE_SIZE                   204
+// Encode Sizes
+#define CODECHAL_ENCODE_STATUS_NUM         512
+#define CODECHAL_ENCODE_SLICESIZE_BUF_SIZE (4960 * sizeof(uint16_t))
 
 typedef struct tagENCODE_RECT
 {
@@ -428,6 +405,99 @@ typedef enum _CODEC_SLICE_STRUCTS
     // 5 - 7 are Reserved
 } CODEC_SLICE_STRUCTS;
 
+enum
+{
+    CODECHAL_ENCODE_PERFTAG_CALL_MBENC_KERNEL,
+    CODECHAL_ENCODE_PERFTAG_CALL_MBENC_PHASE1_KERNEL = CODECHAL_ENCODE_PERFTAG_CALL_MBENC_KERNEL,
+    CODECHAL_ENCODE_PERFTAG_CALL_MBENC_PHASE2_KERNEL,
+    CODECHAL_ENCODE_PERFTAG_CALL_SCALING_KERNEL,
+    CODECHAL_ENCODE_PERFTAG_CALL_INTRA_DIST,
+    CODECHAL_ENCODE_PERFTAG_CALL_ME_KERNEL,
+    CODECHAL_ENCODE_PERFTAG_CALL_BRC_INIT_RESET,
+    CODECHAL_ENCODE_PERFTAG_CALL_BRC_UPDATE,
+    CODECHAL_ENCODE_PERFTAG_CALL_BRC_COPY,
+    CODECHAL_ENCODE_PERFTAG_CALL_PAK_ENGINE,
+    CODECHAL_ENCODE_PERFTAG_CALL_PAK_KERNEL,
+    CODECHAL_ENCODE_PERFTAG_CALL_PAK_PHASE1_KERNEL = CODECHAL_ENCODE_PERFTAG_CALL_PAK_KERNEL,
+    CODECHAL_ENCODE_PERFTAG_CALL_PAK_PHASE2_KERNEL,
+    CODECHAL_ENCODE_PERFTAG_CALL_UPSCALING,
+    CODECHAL_ENCODE_PERFTAG_CALL_DEBLOCKING,
+    CODECHAL_ENCODE_PERFTAG_CALL_WP_KERNEL,
+    CODECHAL_ENCODE_PERFTAG_CALL_32X32_PU_MD,
+    CODECHAL_ENCODE_PERFTAG_CALL_32X32_B_IC,
+    CODECHAL_ENCODE_PERFTAG_CALL_16X16_PU_MD,
+    CODECHAL_ENCODE_PERFTAG_CALL_16X16_SAD,
+    CODECHAL_ENCODE_PERFTAG_CALL_8X8_PU,
+    CODECHAL_ENCODE_PERFTAG_CALL_8X8_FMODE,
+    CODECHAL_ENCODE_PERFTAG_CALL_BRC_UPDATE_LCU,
+    CODECHAL_ENCODE_PERFTAG_CALL_MBENC_I_32x32,
+    CODECHAL_ENCODE_PERFTAG_CALL_MBENC_I_16x16,
+    CODECHAL_ENCODE_PERFTAG_CALL_MBENC_P,
+    CODECHAL_ENCODE_PERFTAG_CALL_MBENC_TX,
+    CODECHAL_ENCODE_PERFTAG_CALL_MBPAK_RECON_LUMA,
+    CODECHAL_ENCODE_PERFTAG_CALL_MBPAK_RECON_CHROMA,
+    CODECHAL_ENCODE_PERFTAG_CALL_MBPAK_RECON_LUMA_32x32,
+    CODECHAL_ENCODE_PERFTAG_CALL_MBPAK_RECON_INTRA_LUMA,
+    CODECHAL_ENCODE_PERFTAG_CALL_MBPAK_RECON_INTRA_CHROMA,
+    CODECHAL_ENCODE_PERFTAG_CALL_MBPAK_DEBLOCK_MASK,
+    CODECHAL_ENCODE_PERFTAG_CALL_MBPAK_DEBLOCK_LUMA,
+    CODECHAL_ENCODE_PERFTAG_CALL_MBPAK_DEBLOCK_CHROMA,
+    CODECHAL_ENCODE_PERFTAG_CALL_MBPAK_MC,
+    CODECHAL_ENCODE_PERFTAG_CALL_PREPROC_KERNEL,
+    CODECHAL_ENCODE_PERFTAG_CALL_DS_CONVERSION_KERNEL,
+    CODECHAL_ENCODE_PERFTAG_CALL_SCOREBOARD,
+    CODECHAL_ENCODE_PERFTAG_CALL_SFD_KERNEL,
+    CODECHAL_ENCODE_PERFTAG_CALL_PAK_ENGINE_SECOND_PASS,
+    CODECHAL_ENCODE_PERFTAG_CALL_BRC_UPDATE_SECOND_PASS,
+    CODECHAL_ENCODE_PERFTAG_CALL_HEVC_LA_UPDATE,
+    CODECHAL_ENCODE_PERFTAG_CALL_VP9_HPU,
+    CODECHAL_ENCODE_PERFTAG_CALL_VP9_HPU_SECOND_PASS
+};
+
+typedef enum _CODECHAL_ENCODE_FUNCTION_ID
+{
+    CODECHAL_ENCODE_ENC_ID           = 0x100,
+    CODECHAL_ENCODE_PAK_ID           = 0x101,
+    CODECHAL_ENCODE_ENC_PAK_ID       = 0x102,
+    CODECHAL_ENCODE_VPP_ID           = 0x103,
+    CODECHAL_ENCODE_FORMAT_COUNT_ID  = 0x104,
+    CODECHAL_ENCODE_FORMATS_ID       = 0x105,
+    CODECHAL_ENCODE_ENC_CTRL_CAPS_ID = 0x106,
+    CODECHAL_ENCODE_ENC_CTRL_GET_ID  = 0x107,
+    CODECHAL_ENCODE_ENC_CTRL_SET_ID  = 0x108,
+    CODECHAL_ENCODE_MBDATA_LAYOUT_ID = 0x109,
+    CODECHAL_ENCODE_FEI_PRE_ENC_ID   = 0x10A,
+    CODECHAL_ENCODE_FEI_ENC_ID       = 0x10B,
+    CODECHAL_ENCODE_FEI_PAK_ID       = 0x10C,
+    CODECHAL_ENCODE_FEI_ENC_PAK_ID   = 0x10D,
+    CODECHAL_ENCODE_QUERY_STATUS_ID  = 0x121
+} CODECHAL_ENCODE_FUNCTION_ID;
+
+//!
+//! \struct    HwCounter
+//! \brief     Hardware counter
+//!
+struct HwCounter
+{
+    uint64_t IV;         // Big-Endian IV
+    uint64_t Count;      // Big-Endian Block Count
+};
+
+//!
+//! \struct CodechalTileInfo
+//! \brief Tile info report to application
+//!
+struct CodechalTileInfo
+{
+    uint16_t    TileRowNum;
+    uint16_t    TileColNum;
+    uint32_t    TileBitStreamOffset;
+    uint32_t    TileSizeInBytes;
+
+    uint32_t    reserved;
+    HwCounter   HWCounterValue;
+};
+
 //FEI Encode Macros
 #define CodecHalIsFeiEncode(codecFunction)              \
     ( codecFunction == CODECHAL_FUNCTION_FEI_PRE_ENC ||  \
@@ -489,4 +559,13 @@ typedef enum _CODEC_SLICE_STRUCTS
 #define CODECHAL_ENCODE_MODE_BIT_OFFSET     ((uint32_t)(log((double)CODECHAL_ENCODE_MODE_AVC)/log(2.)))
 #define CODECHAL_ENCODE_MODE_BIT_MASK       (( 1L << CODECHAL_ENCODE_MODE_BIT_OFFSET) - 1 )
 
+template<typename ValueType>
+static ValueType SwapEndianness(ValueType value)
+{
+    uint8_t*    startLocation = reinterpret_cast<uint8_t*>(&value);
+    uint8_t*    endLocation = startLocation + sizeof(ValueType);
+    std::reverse(startLocation, endLocation);
+    return value;
+}
+
 #endif  // __CODEC_DEF_COMMON_ENCODE_H__
